@@ -14,12 +14,12 @@ import subprocess
 logger = None
 
 class AppServer(Config):
-    bool_options = ['debug', 'log_debug', 'auto_start_servers',
-        'get_public_ip', 'inline_certs']
-    int_options = ['port', 'session_timeout', 'key_bits', 'dh_param_bits']
-    path_options = ['log_path', 'db_path', 'www_path', 'data_path',
-        'server_cert_path', 'server_key_path']
-    str_options = ['bind_addr', 'password']
+    bool_options = {'debug', 'log_debug', 'auto_start_servers',
+        'get_public_ip', 'inline_certs'}
+    int_options = {'port', 'session_timeout', 'key_bits', 'dh_param_bits'}
+    path_options = {'log_path', 'db_path', 'www_path', 'data_path',
+        'server_cert_path', 'server_key_path'}
+    str_options = {'bind_addr', 'password', 'public_ip_server'}
     default_options = {
         'auto_start_servers': True,
         'get_public_ip': True,
@@ -30,6 +30,7 @@ class AppServer(Config):
         'db_path': DEFAULT_DB_PATH,
         'www_path': DEFAULT_WWW_PATH,
         'data_path': DEFAULT_DATA_PATH,
+        'public_ip_server': DEFAULT_PUBLIC_IP_SERVER,
     }
 
     def __init__(self):
@@ -39,25 +40,26 @@ class AppServer(Config):
         self.mem_db = None
         self.interrupt = False
 
-    def load_public_ip(self, retry=False):
+    def load_public_ip(self, retry=False, timeout=3):
         if not self.get_public_ip:
             return
         logger.debug('Getting public ip address...')
         try:
-            request = urllib2.Request(PUBLIC_IP_SERVER)
-            response = urllib2.urlopen(request, timeout=5)
+            request = urllib2.Request(self.public_ip_server)
+            response = urllib2.urlopen(request, timeout=timeout)
             self.public_ip = json.load(response)['ip']
         except:
             if retry:
                 logger.debug('Retrying get public ip address...')
                 time.sleep(1)
-                self.load_public_ip()
+                self.load_public_ip(timeout=timeout)
             else:
                 logger.exception('Failed to get public ip address...')
 
     def _setup_public_ip(self):
         self.public_ip = None
-        threading.Thread(target=self.load_public_ip).start()
+        threading.Thread(target=self.load_public_ip,
+            kwargs={'retry': True, 'timeout': 10}).start()
 
     def _setup_app(self):
         import flask
@@ -69,15 +71,23 @@ class AppServer(Config):
 
     def auth(self, call):
         import flask
+        from auth_token import AuthToken
         def _wrapped(*args, **kwargs):
-            if 'timestamp' not in flask.session:
-                raise flask.abort(401)
+            if flask.request.json and 'auth_token' in flask.request.json and \
+                    flask.request.json['auth_token']:
+                auth_token = AuthToken(flask.request.json['auth_token'])
+                if not auth_token.valid:
+                    raise flask.abort(401)
 
-            # Disable session timeout if set to 0
-            if self.session_timeout and time.time() - flask.session[
-                    'timestamp'] > self.session_timeout:
-                flask.session.pop('timestamp', None)
-                raise flask.abort(401)
+            else:
+                if 'timestamp' not in flask.session:
+                    raise flask.abort(401)
+
+                # Disable session timeout if set to 0
+                if self.session_timeout and time.time() - flask.session[
+                        'timestamp'] > self.session_timeout:
+                    flask.session.pop('timestamp', None)
+                    raise flask.abort(401)
             return call(*args, **kwargs)
         _wrapped.__name__ = '%s_auth' % call.__name__
         return _wrapped
@@ -136,24 +146,36 @@ class AppServer(Config):
             with open(os.path.join(self.www_path, 'index.html'), 'r') as fd:
                 return fd.read()
 
+    def _get_version_int(self, version):
+        return int(''.join([x.zfill(2) for x in version.split('.')]))
+
     def _upgrade_data(self):
         from pritunl import __version__
-        version = '0.10.1'
+        version = self._get_version_int(__version__)
+        cur_version = '0.10.1'
         version_path = os.path.join(self.data_path, VERSION_NAME)
         if os.path.isfile(version_path):
             with open(version_path, 'r') as version_file:
-                version = version_file.readlines()[0].strip()
+                cur_version = version_file.readlines()[0].strip()
+        cur_version = self._get_version_int(cur_version)
 
-        if version == '0.10.1':
-            logger.info('Upgrading data from v0.10.1...')
+        if cur_version < self._get_version_int('0.10.2'):
+            logger.info('Upgrading data to v0.10.2...')
             from organization import Organization
             for org in Organization.get_orgs():
                 for user in org.get_users():
                     user._upgrade_0_10_2()
 
-        if version != __version__:
+        if cur_version < self._get_version_int('0.10.4'):
+            logger.info('Upgrading data to v0.10.4...')
+            from organization import Organization
+            for org in Organization.get_orgs():
+                for user in org.get_users():
+                    user._upgrade_0_10_4()
+
+        if cur_version != version:
             with open(version_path, 'w') as version_file:
-                version = version_file.write('%s\n' % __version__)
+                version_file.write('%s\n' % __version__)
 
     def _hash_password(self, password):
         password_hash = hashlib.sha512()
@@ -225,7 +247,8 @@ class AppServer(Config):
                     server.start()
 
         server = cherrypy.wsgiserver.CherryPyWSGIServer(
-            (self.bind_addr, self.port), self.app)
+            (self.bind_addr, self.port), self.app,
+            server_name=cherrypy.wsgiserver.CherryPyWSGIServer.version)
         server.ssl_adapter = cherrypy.wsgiserver.ssl_builtin.BuiltinSSLAdapter(
             self._server_cert_path, self._server_key_path)
         try:
