@@ -3,22 +3,23 @@ import os
 import logging
 
 logger = logging.getLogger(APP_NAME)
-_RESERVED_ATTRIBUTES = ['bool_options', 'int_options', 'float_options',
+_RESERVED_ATTRIBUTES = {'bool_options', 'int_options', 'float_options',
     'path_options', 'str_options', 'list_options', 'default_options',
-    'all_options']
+    'all_options'}
 
 class Config:
-    bool_options = []
-    int_options = []
-    float_options = []
-    path_options = []
-    str_options = []
-    list_options = []
+    bool_options = set()
+    int_options = set()
+    float_options = set()
+    path_options = set()
+    str_options = set()
+    list_options = set()
     default_options = {}
+    chmod_mode = None
 
     def __init__(self, path=None):
-        self.all_options = self.bool_options + self.int_options + \
-            self.float_options + self.path_options + self.str_options
+        self.all_options = self.bool_options | self.int_options | \
+            self.float_options | self.path_options | self.str_options
         self._conf_path = path
         self._loaded = False
         self.set_state(SAVED)
@@ -66,9 +67,9 @@ class Config:
 
     def _decode_bool(self, value):
         value = value.lower()
-        if value in ['true', 't', 'yes', 'y']:
+        if value in {'true', 't', 'yes', 'y'}:
             return True
-        elif value in ['false', 'f', 'no', 'n']:
+        elif value in {'false', 'f', 'no', 'n'}:
             return False
         else:
             raise ValueError('Value is not boolean')
@@ -171,21 +172,30 @@ class Config:
             if not merge:
                 raise
 
-    def commit(self, chmod_mode=None):
+    def commit(self):
         logger.debug('Committing config.')
         if not self._loaded:
             self.load(True)
 
-        with open(self._conf_path, 'w') as config:
-            if chmod_mode:
-                os.chmod(self._conf_path, 0600)
+        try:
+            temp_conf_path = self._conf_path + CONF_TEMP_EXT
+            with open(temp_conf_path, 'w') as config:
+                if self.chmod_mode:
+                    os.chmod(temp_conf_path, self.chmod_mode)
 
-            for name in self.all_options:
-                if name not in self.__dict__:
-                    continue
-                value = self.__dict__[name]
-                if value is None:
-                    continue
-                config.write(self._encode_line(name, value))
+                for name in self.all_options:
+                    if name not in self.__dict__:
+                        continue
+                    value = self.__dict__[name]
+                    if value is None:
+                        continue
+                    config.write(self._encode_line(name, value))
+            os.rename(temp_conf_path, self._conf_path)
+        except:
+            try:
+                os.remove(temp_conf_path)
+            except OSError:
+                pass
+            raise
 
         self.set_state(SAVED)
