@@ -1,8 +1,9 @@
+import string
+
 APP_NAME = 'pritunl'
 APP_NAME_FORMATED = 'Pritunl'
 CONF_FILENAME = '%s.conf' % APP_NAME
 
-PUBLIC_IP_SERVER = 'http://ip.pritunl.com/'
 
 SAVED = 'saved'
 UNSAVED = 'unsaved'
@@ -18,6 +19,7 @@ DEFAULT_PRIMARY_INTERFACE = 'eth0'
 DEFAULT_SESSION_TIMEOUT = 86400
 DEFAULT_PASSWORD = 'admin'
 PASSWORD_SALT = '2511cebca93d028393735637bbc8029207731fcf'
+DEFAULT_CONF_PATH = '/etc/pritunl.conf'
 DEFAULT_DB_PATH = '/var/lib/pritunl/pritunl.db'
 DEFAULT_WWW_PATH = '/usr/share/pritunl/www'
 DEFAULT_DATA_PATH = '/var/lib/pritunl'
@@ -25,12 +27,22 @@ DEFAULT_LOG_LIMIT = 20
 DEFAULT_KEY_BITS = 4096
 DEFAULT_DH_PARAM_BITS = 1536
 DEFAULT_OTP_SECRET_LEN = 16
+DEFAULT_PUBLIC_IP_SERVER = 'http://ip.pritunl.com/json'
+DATABASE_CLEAN_INTERVAL = 600
+EVENT_DB_TTL = 61000
+RATE_LIMIT_SLEEP = 0.5
+SHORT_URL_LEN = 5
+SHORT_URL_CHARS = (string.ascii_lowercase + string.ascii_uppercase +
+    string.digits).replace('l', '').replace('I', '').replace('O', '').replace(
+    '0', '')
+THREAD_EVENT_TIMEOUT = 15
 
 INFO = 'info'
 WARNING = 'warning'
 ERROR = 'error'
 
 VERSION_NAME = 'version'
+AUTH_USER_NAME = 'admin'
 ORGS_DIR = 'organizations'
 SERVERS_DIR = 'servers'
 REQS_DIR = 'reqs'
@@ -55,6 +67,7 @@ SERVER_CERT_NAME = 'server.crt'
 SERVER_KEY_NAME = 'server.key'
 OTP_JSON_NAME = 'otp.json'
 AUTH_LOG_NAME = 'auth.log'
+CONF_TEMP_EXT = '.tmp'
 
 CA_CERT_ID = 'ca'
 CERT_CA = 'ca'
@@ -152,6 +165,9 @@ subjectKeyIdentifier = hash
 authorityKeyIdentifier = keyid:always
 """
 
+MISSING_PARAMS = 'missing_params'
+MISSING_PARAMS_MSG = 'Missing required parameters.'
+
 AUTH_NOT_VALID = 'auth_not_valid'
 AUTH_NOT_VALID_MSG = 'Username or password is not valid.'
 
@@ -201,6 +217,7 @@ dh %s
 server %s
 ifconfig-pool-persist %s
 push "%s"
+max-clients 1024
 keepalive 4 10
 persist-tun
 status %s 1
@@ -223,6 +240,16 @@ verb 2
 mute 3
 """
 
+OVPN_INLINE_CLIENT_CONF = """client
+dev tun
+proto %s
+remote %s %s
+nobind
+persist-tun
+verb 2
+mute 3
+"""
+
 # Script will run in python 2 and 3
 TLS_VERIFY_SCRIPT = """#!/usr/bin/env python
 import os
