@@ -6,11 +6,14 @@ from log_entry import LogEntry
 from user import User
 import uuid
 import os
-import shutil
 import subprocess
+import utils
+import logging
+
+logger = logging.getLogger(APP_NAME)
 
 class Organization(Config):
-    str_options = ['name']
+    str_options = {'name'}
 
     def __init__(self, id=None, name=None):
         Config.__init__(self)
@@ -37,11 +40,19 @@ class Organization(Config):
 
         self.ca_cert = User(self, id=CA_CERT_ID)
 
+    def __getattr__(self, name):
+        if name == 'otp_auth':
+            for server in self.get_servers():
+                if server.otp_auth:
+                    return True
+            return False
+        return Config.__getattr__(self, name)
+
     def _initialize(self):
         self._make_dirs()
         self.ca_cert = User(self, type=CERT_CA)
         self.commit()
-        LogEntry(message='Created new organization.')
+        LogEntry(message='Created new organization "%s".' % self.name)
         Event(type=ORGS_UPDATED)
 
     def _make_dirs(self):
@@ -72,9 +83,24 @@ class Organization(Config):
                 user_id = user_id.replace('.crt', '')
                 if user_id == CA_CERT_ID:
                     continue
-                users.append(User(self, id=user_id))
+                user = User(self, id=user_id)
+                try:
+                    user.load()
+                except IOError:
+                    logger.exception('Failed to load user conf, ' +
+                        'ignoring user. %r' % {
+                            'user_id': user_id,
+                        })
+                    continue
+                users.append(user)
         return users
 
+    def get_server(self, server_id):
+        from server import Server
+        server = Server(server_id)
+        if self.id in server.organizations:
+            return server
+
     def get_servers(self):
         from server import Server
         servers = []
@@ -118,13 +144,15 @@ class Organization(Config):
         Event(type=ORGS_UPDATED)
 
     def remove(self):
+        name = self.name
+
         for server in self.get_servers():
             if server.status:
                 server.stop()
             server.remove_org(self.id)
 
-        shutil.rmtree(self.path)
-        LogEntry(message='Deleted organization.')
+        utils.rmtree(self.path)
+        LogEntry(message='Deleted organization "%s".' % name)
         Event(type=ORGS_UPDATED)
 
     @staticmethod
@@ -133,5 +161,14 @@ class Organization(Config):
         orgs = []
         if os.path.isdir(path):
             for org_id in os.listdir(path):
-                orgs.append(Organization(org_id))
+                org = Organization(org_id)
+                try:
+                    org.load()
+                except IOError:
+                    logger.exception('Failed to load organization conf, ' +
+                        'ignoring organization. %r' % {
+                            'org_id': org_id,
+                        })
+                    continue
+                orgs.append(org)
         return orgs
