@@ -8,25 +8,26 @@ import uuid
 import os
 import signal
 import time
-import shutil
 import subprocess
 import threading
 import logging
 import traceback
+import utils
 
 logger = logging.getLogger(APP_NAME)
 _threads = {}
+_events = {}
 _output = {}
 _process = {}
 _start_time = {}
 
 class Server(Config):
-    str_options = ['name', 'network', 'interface', 'protocol',
+    str_options = {'name', 'network', 'interface', 'protocol',
         'local_network', 'public_address', 'primary_organization',
-        'primary_user', 'organizations']
-    bool_options = ['otp_auth', 'lzo_compression', 'debug']
-    int_options = ['port']
-    list_options = ['organizations']
+        'primary_user', 'organizations'}
+    bool_options = {'otp_auth', 'lzo_compression', 'debug'}
+    int_options = {'port'}
+    list_options = {'organizations'}
 
     def __init__(self, id=None, name=None, network=None, interface=None,
             port=None, protocol=None, local_network=None, public_address=None,
@@ -78,6 +79,10 @@ class Server(Config):
             if self.status and self.id in _start_time:
                 return int(time.time()) - _start_time[self.id]
             return None
+        elif name == 'user_count':
+            return self._get_user_count()
+        elif name == 'org_count':
+            return self._get_org_count()
 
         return Config.__getattr__(self, name)
 
@@ -89,12 +94,12 @@ class Server(Config):
         try:
             self._generate_dh_param()
             self.commit()
-            LogEntry(message='Created new server.')
+            LogEntry(message='Created new server "%s".' % self.name)
         except:
             logger.exception('Failed to create server. %r' % {
                 'server_id': self.id,
             })
-            shutil.rmtree(self.path)
+            utils.rmtree(self.path)
             raise
 
     def _event_delay(self, type, resource_id=None):
@@ -119,6 +124,9 @@ class Server(Config):
         logger.info('Removing server. %r' % {
             'server_id': self.id,
         })
+
+        name = self.name
+
         if self.status:
             self.force_stop()
             for i in xrange(20):
@@ -128,9 +136,10 @@ class Server(Config):
             if self.status:
                 self.force_stop()
                 time.sleep(0.5)
+
         self._remove_primary_user()
-        shutil.rmtree(self.path)
-        LogEntry(message='Deleted server.')
+        utils.rmtree(self.path)
+        LogEntry(message='Deleted server "%s".' % name)
         Event(type=SERVERS_UPDATED)
 
     def commit(self):
@@ -170,11 +179,12 @@ class Server(Config):
                 'server_id': self.id,
                 'org_id': org.id,
             })
-            return
+            return org
         self.organizations.append(org.id)
         self.commit()
         Event(type=SERVERS_UPDATED)
         Event(type=SERVER_ORGS_UPDATED, resource_id=self.id)
+        return org
 
     def _remove_primary_user(self):
         logger.debug('Removing primary user. %r' % {
@@ -230,6 +240,19 @@ class Server(Config):
             orgs.append(org)
         return orgs
 
+    def _get_user_count(self):
+        server_orgs = self.get_orgs()
+        users_count = 0
+        for org in server_orgs:
+            for user in org.get_users():
+                if user.type != CERT_CLIENT:
+                    continue
+                users_count += 1
+        return users_count
+
+    def _get_org_count(self):
+        return len(self.get_orgs())
+
     def _generate_dh_param(self):
         logger.debug('Generating server dh params. %r' % {
             'server_id': self.id,
@@ -476,6 +499,11 @@ class Server(Config):
                 i += 1
             time.sleep(0.1)
         self._clear_iptable_rules()
+        _events[self.id].set()
+        try:
+            del _events[self.id]
+        except KeyError:
+            pass
 
     def _run(self):
         logger.debug('Starting ovpn process. %r' % {
@@ -489,6 +517,7 @@ class Server(Config):
                 process = subprocess.Popen(['openvpn', self.ovpn_conf_path],
                     stdout=subprocess.PIPE, stderr=subprocess.PIPE)
                 _process[self.id] = process
+                _events[self.id].set()
             except OSError:
                 _output[self.id] += traceback.format_exc()
                 self._event_delay(type=SERVER_OUTPUT_UPDATED,
@@ -510,7 +539,6 @@ class Server(Config):
                 'server_id': self.id,
             })
         finally:
-            self._interrupt = True
             try:
                 del _threads[self.id]
             except KeyError:
@@ -523,9 +551,9 @@ class Server(Config):
                 del _start_time[self.id]
             except KeyError:
                 pass
-            Event(type=SERVERS_UPDATED)
+            self._interrupt = True
 
-    def start(self):
+    def start(self, silent=False):
         if self.status:
             return
         if not self.get_orgs():
@@ -537,41 +565,59 @@ class Server(Config):
         self._generate_ovpn_conf()
         self._enable_ip_forwarding()
         self._set_iptables_rule()
+        _events[self.id] = threading.Event()
         thread = threading.Thread(target=self._run)
         thread.start()
         _threads[self.id] = thread
         _start_time[self.id] = int(time.time()) - 1
         _output[self.id] = ''
-        Event(type=SERVERS_UPDATED)
-        LogEntry(message='Started server "%s".' % self.name)
+        if not _events[self.id].wait(THREAD_EVENT_TIMEOUT):
+            raise ValueError('Server thread failed to return start event.')
+        try:
+            _events[self.id].clear()
+        except KeyError:
+            pass
+        if not silent:
+            Event(type=SERVERS_UPDATED)
+            LogEntry(message='Started server "%s".' % self.name)
 
-    def stop(self):
+    def stop(self, silent=False):
         if not self.status:
             return
         logger.debug('Stopping server. %r' % {
             'server_id': self.id,
         })
         _process[self.id].send_signal(signal.SIGINT)
-        LogEntry(message='Stopped server "%s".' % self.name)
+        if not _events[self.id].wait(THREAD_EVENT_TIMEOUT):
+            raise ValueError('Server thread failed to return stop event.')
+        if not silent:
+            Event(type=SERVERS_UPDATED)
+            LogEntry(message='Stopped server "%s".' % self.name)
 
-    def force_stop(self):
+    def force_stop(self, silent=False):
         if not self.status:
             return
         logger.info('Forcing stop server. %r' % {
             'server_id': self.id,
         })
         _process[self.id].send_signal(signal.SIGKILL)
-        LogEntry(message='Stopped server "%s".' % self.name)
+        if not _events[self.id].wait(THREAD_EVENT_TIMEOUT):
+            raise ValueError('Server thread failed to return stop event.')
+        if not silent:
+            Event(type=SERVERS_UPDATED)
+            LogEntry(message='Stopped server "%s".' % self.name)
 
-    def restart(self):
+    def restart(self, silent=False):
         if not self.status:
             self.start()
         logger.debug('Restarting server. %r' % {
             'server_id': self.id,
         })
-        self.generate_ca_cert()
-        _process[self.id].send_signal(signal.SIGHUP)
-        LogEntry(message='Restarted server "%s".' % self.name)
+        self.stop(True)
+        self.start(True)
+        if not silent:
+            Event(type=SERVERS_UPDATED)
+            LogEntry(message='Restarted server "%s".' % self.name)
 
     def reload(self):
         if not self.status:
@@ -579,7 +625,6 @@ class Server(Config):
         logger.debug('Reloading server. %r' % {
             'server_id': self.id,
         })
-        self.generate_ca_cert()
         _process[self.id].send_signal(signal.SIGUSR1)
         LogEntry(message='Reloaded server "%s".' % self.name)
 
@@ -638,5 +683,5 @@ class Server(Config):
                             'server_id': server_id,
                         })
                     continue
-                servers.append(Server(server_id))
+                servers.append(server)
         return servers
