@@ -14,7 +14,8 @@ import base64
 logger = logging.getLogger(APP_NAME)
 
 class User(Config):
-    str_options = ['name', 'otp_secret']
+    str_options = {'name', 'otp_secret', 'type'}
+    chmod_mode = 0600
 
     def __init__(self, org, id=None, name=None, type=None):
         Config.__init__(self)
@@ -54,29 +55,40 @@ class User(Config):
         if not self._initialized:
             self._initialize()
 
-    def __getattr__(self, name):
-        if name == 'type':
-            self.type = self._load_type()
-            return self.type
-        return Config.__getattr__(self, name)
-
     def _upgrade_0_10_2(self):
         if not self.otp_secret:
-            logger.debug('Upgrading user from v0.10.1... %r' % {
+            logger.debug('Upgrading user to v0.10.2... %r' % {
                 'org_id': self.org.id,
                 'user_id': self.id,
             })
             self._generate_otp_secret()
-            self.commit(0600)
+            self.commit()
+
+    def _upgrade_0_10_4(self):
+        if not self.type:
+            logger.debug('Upgrading user to v0.10.4... %r' % {
+                'org_id': self.org.id,
+                'user_id': self.id,
+            })
+            with open(self.cert_path, 'r') as cert_file:
+                cert_data = cert_file.read()
+                if 'CA:TRUE' in cert_data:
+                    self.type = CERT_CA
+                elif 'TLS Web Server Authentication' in cert_data:
+                    self.type = CERT_SERVER
+                else:
+                    self.type = CERT_CLIENT
+            self.commit()
 
     def _initialize(self):
         self._create_ssl_conf()
         self._cert_request()
         self._generate_otp_secret()
-        self.commit(0600)
+        self.commit()
         self._cert_create()
         self._delete_ssl_conf()
-        LogEntry(message='Created new user.')
+        if self.type == CERT_CLIENT:
+            LogEntry(message='Created new user "%s".' % self.name)
         Event(type=USERS_UPDATED)
 
     def _cert_request(self):
@@ -145,19 +157,9 @@ class User(Config):
 
     def generate_otp_secret(self):
         self._generate_otp_secret()
-        self.commit(0600)
+        self.commit()
         Event(type=USERS_UPDATED)
 
-    def _load_type(self):
-        with open(self.cert_path, 'r') as cert_file:
-            cert_data = cert_file.read()
-            if 'CA:TRUE' in cert_data:
-                return CERT_CA
-            elif 'TLS Web Server Authentication' in cert_data:
-                return CERT_SERVER
-            else:
-                return  CERT_CLIENT
-
     def _revoke(self, reason):
         if self.id == CA_CERT_ID:
             raise TypeError('Cannot revoke ca cert')
@@ -250,12 +252,9 @@ class User(Config):
                     self.org.name, self.name, server.name)
                 server.generate_ca_cert()
 
-                client_conf = OVPN_CLIENT_CONF % (
+                client_conf = OVPN_INLINE_CLIENT_CONF % (
                     server.protocol,
                     server.public_address, server.port,
-                    '[inline]',
-                    '[inline]',
-                    '[inline]',
                 )
 
                 if server.otp_auth:
@@ -284,12 +283,39 @@ class User(Config):
         else:
             return self._build_key_archive()
 
+    def build_key_conf(self, server_id):
+        server = self.org.get_server(server_id)
+        conf_name = '%s_%s_%s.ovpn' % (self.org.name, self.name, server.name)
+        server.generate_ca_cert()
+
+        client_conf = OVPN_INLINE_CLIENT_CONF % (
+            server.protocol,
+            server.public_address, server.port,
+        )
+
+        if server.otp_auth:
+            client_conf += 'auth-user-pass\n'
+
+        client_conf += '<ca>\n%s\n</ca>\n' % self._get_cert_block(
+            server.ca_cert_path)
+        client_conf += '<cert>\n%s\n</cert>\n' % self._get_cert_block(
+            self.cert_path)
+        client_conf += '<key>\n%s\n</key>\n' % open(
+            self.key_path).read().strip()
+
+        return {
+            'name': conf_name,
+            'conf': client_conf,
+        }
+
     def rename(self, name):
         self.name = name
         self.commit()
         Event(type=USERS_UPDATED)
 
     def remove(self, reason=UNSPECIFIED):
+        name = self.name
+        type = self.type
         self._revoke(reason)
 
         try:
@@ -338,4 +364,5 @@ class User(Config):
             })
 
         Event(type=USERS_UPDATED)
-        LogEntry(message='Deleted user.')
+        if type == CERT_CLIENT:
+            LogEntry(message='Deleted user "%s".' % name)
