@@ -8,6 +8,7 @@ define([
     defaults: {
       'id': null,
       'organization': null,
+      'organization_name': null,
       'name': null,
       'type': null,
       'status': null,
@@ -25,7 +26,7 @@ define([
       return url;
     },
     destroyOtpSecret: function(options) {
-      this.destroy(_.extend({
+      this.save(null, _.extend({
         url: this.url() + '/otp_secret'
       }, options));
     }
