@@ -12,6 +12,7 @@ define([
     template: _.template(modalDeleteServerTemplate),
     title: 'Delete Server',
     okText: 'Delete',
+    inputMatch: true,
     initialize: function() {
       ModalDeleteServerView.__super__.initialize.call(this);
       var alertView = new AlertView({
@@ -21,22 +22,19 @@ define([
       });
       this.addView(alertView);
       this.$('.modal-body').prepend(alertView.render().el);
+      this.inputMatchText = this.model.get('name');
     },
     body: function() {
       return this.template();
     },
     onOk: function() {
-      if (this.$('input').val() !== this.model.get('name')) {
-        this.setAlert('info', 'Name entered doesn\'t match the name ' +
-          'of the server being deleted.', '.form-group');
-        return;
-      }
       this.setLoading('Deleting server...');
       this.model.destroy({
         success: function() {
           this.close(true);
         }.bind(this),
         error: function() {
+          this.clearLoading();
           this.setAlert('danger',
             'Failed to delete server, server error occurred.');
         }.bind(this)
