@@ -128,13 +128,11 @@ define([
       this.addView(modal);
     },
     onGetKeyLink: function() {
-      if (window.demo) {
-        return;
-      }
       var modal = new ModalKeyLinkView({
         model: new KeyModel({
           'organization': this.model.get('organization'),
-          'user': this.model.get('id')
+          'user': this.model.get('id'),
+          'otp_auth': this.model.get('otp_auth')
         })
       });
       this.addView(modal);
